package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0D```````````(``P`!````PI@$"#0```!<L@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"`T````-````!`````$````!``````````"`!`@`@`0(G*T`
M`)RM```%`````!````$```#@K@``X#X%".`^!0A(`@``M`8```8`````$```
M`@```.RN``#L/@4([#X%"!`!```0`0``!@````0````$````9`$``&2!!`AD
M@00(1````$0````$````!````%#E=&2(GP``B!\%"(@?!0CD````Y`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DX*X`
M`.`^!0C@/@4((`$``"`!```$`````0```"]L:6(O;&0N<V\N,0`````$````
M$`````$```!'3E4``P````@````#``````````0````4`````P```$=.50#E
M]0BXKYW@$+(1:7A`WEXF.WZ+K24```!$````"`````@`````'!`$)4`$@C@!
M0`&BA@&HP`$``DLH!"DXHC)'B@0,"$0```!&````````````````````2```
M`$H```!+`````````$P```!-````3P```%````!1````4@````````!4````
M``````````!5````5@```%D``````````````%H```!<````70```%\`````
M````8````&(``````````````&0```!E````9@````````#(U;)Q6>CM[,[>
M1RVCX/M)ZM/O#J?=HVLOQ9NVV\WCGH?YG(%6I)N6:PE#UCGRBQP-.I<+Q8D%
MD`P4XIZ)!W#3(?_D#@N*$%?$N9Q`:G^:?+,!BV]_J9R;;L7?']EQ6!R[XY)\
MK$OCP-5DU'PS8MOM>O!*:V>OS&9"1=7LXT?&`7U!CL7#Y3\L\MO3'?JA;&"Y
MC?$.`````````````````````&4#`````````````!(```#F`@``````````
M```2````F@,`````````````$@```$D"`````````````!(````1````````
M```````@````4`(`````````````$@```,,"`````````````!(```"9`@``
M```````````2````T0(`````````````$@```-,``````````````!(```",
M`P`````````````2````KP``````````````$@```#T!`````````````!(`
M``#?`@`````````````2````JP(`````````````$@```*8!````````````
M`!(```!L`P`````````````2````9@$`````````````$@```.$`````````
M`````!(```#P`0`````````````2````C0$`````````````$@```)$"````
M`````````!(```!Z`@`````````````2````W0$`````````````$@```"\"
M`````````````!(````P`P`````````````2````'0,`````````````$@``
M`'0!`````````````!(```!8`P`````````````2````H@(`````````````
M$@```$,"`````````````!(````M```````````````@````*`,`````````
M````$@```'@``````````````!(```#M`@`````````````2````DP,`````
M````````$@```!0!`````````````!(````*!``````````````2````O@``
M````````````$@```&D"`````````````!(```";`0`````````````2````
M00,`````````````$@```&H``````````````!(```"$`P`````````````2
M````0@$`````````````$@```$<!`````````````!(````(`P``````````
M```2````#P,`````````````$@```-(!`````````````!(````A`0``````
M```````2````40,`````````````$@```/0"`````````````!(```"T`0``
M```````````2````O`(`````````````$@```,D"`````````````!(````\
M```````````````@````^```````````````$@```(0!`````````````!(`
M``#8`@`````````````2````2`,`````````````$@```&$"````````````
M`!(```#Z`@`````````````2````AP``````````````$@```%``````````
M`````"````#I`0`````````````2````C`(`````````````$@```'8#````
M`````````!(```!3`0```)4$"``````2````>P0``$C@!`@$````$0`/`#@$
M``"0S@0(5PP``!(`#0""!````,L$"+<!```2``T`X0,``#3@!`@`````$@`.
M`*X#``!`004(!````"$`&0#G`P``$,@$"`,````2``T`800``,#?!`AA````
M$@`-`)X```#0E00(`````!(````R`0``2$$%"`0````1`!D`100``!A!!0@`
M````$``8`#H#``!D004(!````!$`&0!'!```&$$%"``````@`!@`K0,``$!!
M!0@$````(0`9`-<#```PX`0(`@```!(`#0!Q!```)$$%"`0````1`!@`EP0`
M`"#(!`B[`0``$@`-``<!``!,004(`0```!$`&0"L`P``0$$%"`0````1`!D`
MIP,``*"6!`@B`@``$@`-`+8$``#`S`0(:0```!(`#0#X`P``,,T$""0````2
M``T`$P0``,#>!`AT````$@`-`,L#```H004(`````!``&0#S````E$4%"```
M```0`!D`4@0``$S@!`@$````$0`/`.`$``#PV@0(S@,``!(`#0!+!```PI@$
M"``````2``T`P@$```"3!`@`````$@```"P$```0R@0(Z````!(`#0#$`P``
M*$$%"``````0`!@`'P0``.#)!`@M````$@`-`,0$``!`WP0(.````!(`#0"/
M!```D,<$""<````2``T`^P$``%!!!0@3````$0`9`*0$``!@S00()@$``!(`
M#0"1!```/)($"``````2``L``&QI8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V5N9`!097)L
M7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=35G!V`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``
M;&EB9&PN<V\N,@!L:6)M+G-O+C$`;&EB<'1H<F5A9"YS;RXP`'!T:')E861?
M9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E
M96LV-`!R96%D`&QI8F,N<V\N,"XQ`%]?<F5G:7-T97)?871F;W)K`&5X:70`
M<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N
M;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE
M;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y
M7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U
M:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I
M<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?
M7V)S<U]S=&%R=`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S
M96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?
M24]?<W1D:6Y?=7-E9`!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]F<%]H
M=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%2
M4U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,P!'3$E"0U\R
M+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````"``(``@`#`````P`"``(`
M`@````(```````(`!`````(````````````"``4````#``(``@````8``@`#
M`````@````(``@````(````#`````@````(``@````(`!@```````@`"````
M`@`"``````````(``@`#``8```````(``@`&`````0`!``$``0`"``$``0``
M`````0`"``$``@`!``$``0````(``0`!``$``0`!``$``0`!``$````!``$`
M`0`!``$````!``$``0`!`!\"```0````(````!-I:0T```,`]@0````````!
M``0`;@(``!``````````=!EI"0``!@``!0``$````'(9:0D```4`#`4``!``
M```4:6D-```$`!@%```0````$VEI#0```@#V!````````/P_!0@&(```0$$%
M"`56``!(004(!4T``$Q!!0@%50``4$$%"`5F``!D004(!4\```Q`!0@'`0``
M$$`%"`<"```40`4(!P,``!A`!0@'!```'$`%"`<&```@0`4(!P<``"1`!0@'
M"```*$`%"`<)```L0`4(!PH``#!`!0@'8```-$`%"`<+```X0`4(!PP``#Q`
M!0@'#0``0$`%"`<.``!$0`4(!P\``$A`!0@'$```3$`%"`<1``!00`4(!Q(`
M`%1`!0@'$P``6$`%"`<4``!<0`4(!Q4``&!`!0@'%@``9$`%"`<7``!H0`4(
M!Q@``&Q`!0@'&0``<$`%"`<:``!T0`4(!QL``'A`!0@''```?$`%"`<=``"`
M0`4(!QX``(1`!0@''P``B$`%"`<@``",0`4(!R$``)!`!0@'(@``E$`%"`<C
M``"80`4(!R0``)Q`!0@')0``H$`%"`<F``"D0`4(!R<``*A`!0@'*```K$`%
M"`<I``"P0`4(!T0``+1`!0@'*@``N$`%"`<K``"\0`4(!RP``,!`!0@'+0``
MQ$`%"`<N``#(0`4(!R\``,Q`!0@',```T$`%"`<Q``#40`4(!S(``-A`!0@'
M,P``W$`%"`<T``#@0`4(!S4``.1`!0@'3```Z$`%"`<V``#L0`4(!S<``/!`
M!0@'.0``]$`%"`<Z``#X0`4(!SL``/Q`!0@'/````$$%"`<]```$004(!SX`
M``A!!0@'/P``#$$%"`=!```0004(!T(``!1!!0@'0P``4X/L".BK!@``@<.[
MK0``BX/\____A<!T!>@&`@``@\0(6\,`_S4$0`4(_R4(0`4(`````/\E#$`%
M"&@`````Z>#_____)1!`!0AH"````.G0_____R440`4(:!````#IP/____\E
M&$`%"&@8````Z;#_____)1Q`!0AH(````.F@_____R4@0`4(:"@```#ID/__
M__\E)$`%"&@P````Z8#_____)2A`!0AH.````.EP_____R4L0`4(:$````#I
M8/____\E,$`%"&A(````Z5#_____)31`!0AH4````.E`_____R4X0`4(:%@`
M``#I,/____\E/$`%"&A@````Z2#_____)4!`!0AH:````.D0_____R5$0`4(
M:'````#I`/____\E2$`%"&AX````Z?#^____)4Q`!0AH@````.G@_O___R50
M0`4(:(@```#IT/[___\E5$`%"&B0````Z<#^____)5A`!0AHF````.FP_O__
M_R5<0`4(:*````#IH/[___\E8$`%"&BH````Z9#^____)61`!0AHL````.F`
M_O___R5H0`4(:+@```#I</[___\E;$`%"&C`````Z6#^____)7!`!0AHR```
M`.E0_O___R5T0`4(:-````#I0/[___\E>$`%"&C8````Z3#^____)7Q`!0AH
MX````.D@_O___R6`0`4(:.@```#I$/[___\EA$`%"&CP````Z0#^____)8A`
M!0AH^````.GP_?___R6,0`4(:``!``#IX/W___\ED$`%"&@(`0``Z=#]____
M)91`!0AH$`$``.G`_?___R680`4(:!@!``#IL/W___\EG$`%"&@@`0``Z:#]
M____):!`!0AH*`$``.F0_?___R6D0`4(:#`!``#I@/W___\EJ$`%"&@X`0``
MZ7#]____):Q`!0AH0`$``.E@_?___R6P0`4(:$@!``#I4/W___\EM$`%"&A0
M`0``Z4#]____);A`!0AH6`$``.DP_?___R6\0`4(:&`!``#I(/W___\EP$`%
M"&AH`0``Z1#]____)<1`!0AH<`$``.D`_?___R7(0`4(:'@!``#I\/S___\E
MS$`%"&B``0``Z>#\____)=!`!0AHB`$``.G0_/___R740`4(:)`!``#IP/S_
M__\EV$`%"&B8`0``Z;#\____)=Q`!0AHH`$``.F@_/___R7@0`4(:*@!``#I
MD/S___\EY$`%"&BP`0``Z8#\____)>A`!0AHN`$``.EP_/___R7L0`4(:,`!
M``#I8/S___\E\$`%"&C(`0``Z5#\____)?1`!0AHT`$``.E`_/___R7X0`4(
M:-@!``#I,/S___\E_$`%"&C@`0``Z2#\____)0!!!0AHZ`$``.D0_/___R4$
M004(:/`!``#I`/S___\E"$$%"&CX`0``Z?#[____)0Q!!0AH``(``.G@^___
M_R40004(:`@"``#IT/O___\E%$$%"&@0`@``Z<#[__^-3"0$@^3P_W'\58GE
M5E-1B<N#[$"+002)1=2+00B)1=!EH10```")1>0QP(U%T%"-1=104>BF_?__
M@\0,:`"5!`AH`)4$"&C0E00(Z(](``"#Q!"`/4Q!!0@`=3'HGOS__X7`HY!%
M!0@/A*D!``"#[`Q0Z`C\__]9_S5(004(Z,S\__^#Q!#&@+4$````@^P,_S5(
M004(Z+3\__^`B&8"```"6O\U2$$%".BA_/__@(AF`@```8L#@\00QT7$````
M`(U0!8E5P-]MP-@%>!\%"-T%@!\%"-G)VNG?X)X/AP(!``"#[`S!X@)2Z%#\
M__^+==2+&X/$$*.$104(QP6(104(!````(L6@_L!QT`$'^($",=`#"+B!`B)
M$(L5)$$%"(E0"+H!````?A*-="8`BPR6B4R0#(/"`3G:=?*#[`S'1)@,````
M`(/#`VH`4%-HP,<$"/\UD$4%".B`_?__@\0@A<")PW11@^P,_S60104(Z$G[
M__^-5>"XX^`$".@,*```@\00A<!T1(/L#/\UD$4%".CW^O__Z.+\__^#Q!")
MV(MUY&4S-10```!U9(UE]%E;7EV-8?S#@^P,_S60104(Z*C]__^#Q!")P^N:
MH8Q%!0B%P'0?@^P,4.@_1@``@\00ZZ504&A0004(:%/@!`CH.?S__XU5X+B8
MX`0(Z(PG``"%P*.,104(#X1Z____Z\7HF/K__X/L#&H!Z+[]__\Q[5Z)X8/D
M\%!44F@PX`0(:,#?!`A15FB@E@0(Z*WY___TN)1%!0AFD&:09I"0BQPDPV:0
M9I!FD&:09I!FD+@K004(+2A!!0B#^`9V&K@`````A<!T$56)Y8/L%&@H004(
M_]"#Q!#)\\.0C70F`+@H004(+2A!!0C!^`*)PL'J'P'0T?AT&[H`````A=)T
M$E6)Y8/L$%!H*$$%"/_2@\00R?/#C70F`(V\)P````"`/6A!!0@`=1-5B>6#
M[`CH?/___\8%:$$%"`')\\-FD+CH/@4(BQ"%TG4%ZY.-=@"Z`````(72=/)5
MB>6#[!10_]*#Q!#)Z77___]FD&:0D%57,>U64X'L#`,``(E$)&B#P#B)="0(
M98L5%````(F4)/P"```QTHD$)(E\)`QFD(L$),=$['P`````QX3LA```````
M``"+5*@$BP2HB<&)QHG7P>$(P>88B=.!X0``_P`)\8G&#ZS^"('F`/\```G.
MB<&)T`^LV1@QTH'A_P```(G3"?&)QHE,['B)P<'F&,'A"('A``#_``G.B<$/
MK-D(#ZS0&('A`/\```GQ)?\````)R(F$[(````"#Q0*#_1`/A6G___^-A"3@
M````C90DX`(``(UV`(M(W#-(!(/`"(M8T#-(I#-8^#-(E#-8H,=`%``````S
M6)")SXG>B=F)^P^LV1_!ZQ^)#"2)\8E<)`0!R0L,)(E($#G0=;J+1"1HBT@,
MBU@0BU`(BW`4BV@$BSB)3"0$BT@8B5PD"(M8'(D4)(ET)`R)3"0PBT@@B5PD
M-(M8)(GXB40D*(EL)"R)3"10`TPD>(E<)%037"1\B=J)RX'#F7F"6HG6@]8`
MB=G!X`6)\XG^B>\/K/X;B<\QTHG="<:+!"0!]XE\)!"+?"0($=6)QHEL)!3W
MUHGSBW0D,"'SB?Z+?"00(<:)="08BVPD&`G=`>^)?"0@B7PD$(L$)(M4)`3'
M1"04`````,=$)!P`````QT0D/`````#'1"1$`````(G5B<>)Q@^L[P+!YAZ+
M5"04QT0D)`````")^8M\)#")S8M,)"@)]0.\)(````");"0XBVPD.(G.]]:)
M^(G7BU0D$`69>8):(W0D""'-]]()]8GIBVPD+`'!BT0D$(G+B<;!X`4/K/X;
MBWPD*`G&`?.)7"08B5PD6(GYB>O!YQX/K-D"B?B)S8M,)`@)Q0.,)(@```")
M;"1`BVPD(('!F7F"6B-4)#@C;"1`B>B)U8M4)!P)Q8M$)!@!Z8G7B<N)QL'@
M!0^L_AL)Q@'SBW0D$(E<)&")7"0@BWPD%(M4)#B)\<'F'L=$)!0`````QT0D
M3`````#'1"0\`````(G[#ZS9`HG-"?4#E"20````B6PD2(ML)%B)T8M4)!B!
MP9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!Z8G7B<N+5"1`B<;!X`4/
MK/X;BWPD',=$)!P`````"<8!\XMT)!B)7"00B5PD6(G[B?'!YAX/K-D"B<T)
M]0.4))@```");"0XBVPD8(G1BU0D(('!F7F"6B-L)#CWTB-4)$B)Z(G5BU0D
M%`G%BT0D$`'IB=>)RXG&P>`%#ZS^&XM\)"0)Q@'SBW0D((E<)&")7"08B?N)
M\<'F'@^LV0*)S0GUB6PD0(M4)$@#E"2@````BVPD6,=$)"0`````QT0D1```
M``#'1"1,`````,=$)#P`````B=&+5"00@<&9>8):(VPD0/?2(U0D.(GHB=6+
M5"0<"<6+1"08`>F)UXG+BU0D.(G&P>`%#ZS^&XM\)!3'1"04``````G&`?.+
M="00B5PD((E<)%B)^XGQP>8>#ZS9`HG-"?4#E"2H````B6PD2(ML)&")T8M4
M)!B!P9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!Z8G7B<N)QL'@!0^L
M_AN+?"0<"<8!\XMT)!B)7"1@B5PD$(G[B?'!YAX/K-D"B<T)]8EL)#B+5"1`
M`Y0DL````(ML)%C'1"0<`````,=$)$0`````QT0D3`````")T8M4)""!P9EY
M@EHC;"0X]](C5"1(B>B)U8M4)!0)Q8M$)!`!Z8G7B<N+5"1(B<;!X`4/K/X;
MBWPD),=$)"0`````"<8!\XMT)"")7"08B5PD6(G[B?'!YAX/K-D"B<T)]0.4
M)+@```");"1`BVPD8(G1BU0D$('!F7F"6B-L)$#WTB-4)#B)Z(G5BU0D'`G%
MBT0D&`'IB=>)RXM4)#B)QL'@!0^L_AN+?"04"<8!\XMT)!")7"1@B5PD((G[
MB?'!YAX/K-D"B<T)]8EL)$@#E"3`````BVPD6,=$)!0`````QT0D/`````#'
M1"1$`````(G1BU0D&('!F7F"6B-L)$CWTB-4)$")Z(G5BU0D)`G%BT0D(`'I
MB=>)RXM4)$")QL'@!0^L_AN+?"0<QT0D'``````)Q@'SBW0D&(E<)!")7"18
MB?N)\<'F'@^LV0*)S0GU`Y0DR````(EL)#B+;"1@B=&+5"0@@<&9>8):(VPD
M./?2(U0D2(GHB=6+5"04"<6+1"00`>F)UXG+BU0D2(G&P>`%#ZS^&XM\)"0)
MQ@'SBW0D((E<)&")7"08B?N)\<'F'@^LV0*)S0GUB6PD0`.4)-````"+;"18
MQT0D)`````#'1"1,`````,=$)#P`````B=&+5"00@<&9>8):(VPD0/?2(U0D
M.(GHB=6+5"0<"<6+1"08`>F)UXG+BU0D.(G&P>`%#ZS^&XM\)!3'1"04````
M``G&`?.+="00B5PD((E<)%B)^XGQP>8>#ZS9`HG-"?4#E"38````B6PD2(ML
M)&")T8M4)!B!P9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!Z8G7B<N+
M5"1`B<;!X`4/K/X;BWPD'`G&`?.+="08B5PD8(E<)!")^XGQP>8>#ZS9`HG-
M"?4#E"3@````B6PD.(G1BU0D((ML)%B!P9EY@EHC;"0XQT0D'`````#'1"1$
M`````,=$)$P`````]](C5"1(B>B)U8M4)!0)Q8M$)!`!Z8G7B<N+5"1(B<;!
MX`4/K/X;BWPD),=$)"0`````"<8!\XMT)"")7"08B5PD6(G[B?'!YAX/K-D"
MB<T)]0.4).@```");"1`BVPD8(G1BU0D$('!F7F"6B-L)$#WTB-4)#B)Z(G5
MBU0D'`G%BT0D&`'IB=>)RXM4)#B)QL'@!0^L_AN+?"04"<8!\XMT)!")7"1@
MB5PD((G[B?'!YAX/K-D"B<T)]0.4)/````");"1(B=&+5"08@<&9>8):]](C
M5"1`BVPD6"-L)$C'1"04`````,=$)#P`````QT0D1`````")Z(G5BU0D)`G%
MBT0D(`'IB=>)RXM4)$")QL'@!0^L_AN+?"0<QT0D'``````)Q@'SBW0D&(E<
M)!")7"18B?N)\<'F'@^LV0*)S0GU`Y0D^````(EL)#B+;"1@B=&+5"0@@<&9
M>8):(VPD./?2(U0D2(GHB=6+5"04"<6+1"00`>F)UXG+BU0D2(G&P>`%#ZS^
M&XM\)"0)Q@'SBW0D((E<)&")7"08B?N)\<'F'@^LV0*)S0GU`Y0D``$``(EL
M)$")T8M4)!"!P9EY@EKWTB-4)#B+;"18(VPD0,=$)"0`````QT0D3`````")
MZ(G5BU0D'`G%BT0D&`'IB=>)RXM4)#B)QL'@!0^L_AN+?"04"<8!\XMT)!")
M7"0@B5PD6(G[B?'!YAX/K-D"B<V+3"0\QT0D/``````)]0.4)`@!```3C"0,
M`0``B6PD2(ML)&")RXG1BU0D&('!F7F"6H/3`"-L)$@Q__?2(U0D0(GHB=6+
M5"0D"<6+1"0@`>D1^XG7,=*)QL'@!0^L_AN+?"0<QT0D'``````)QHGPB=Z)
MRP'#$=:)7"1@B5PD.(ET)&2+="08B?N+5"1`B?'!YAX/K-D"B<T)]8EL)&R)
M;"08`Y0D$`$``(MT)%B+1"0XQT0D%`````")T8M4)""!P9EY@EHA[HML)&SW
MTB-4)$@)\HG&`=&+5"0\P>`%B<N)UXM4)$@/K/X;BWPD)`G&`?.+="0@B5PD
M0(E<)!")^XGQP>8>#ZS9`HGPB<X)Q@.4)!@!``")="0@B="+5"04!:'KV6XQ
M]8GNBVPD8(G7BU0D/#'UB>D!P8M$)!")RXG&P>`%B40D2(ML)$@/K/X;BT0D
M.`GU`>LQ_XML)$")WHE<)$B)P8G3P>`>BU0D&`^LV0*)RPG#`Y0D(`$``(E<
M)#B)T(GZ!:'KV6XS7"0@,=V)Z0'!B?`/K-`;B40D&(GPBVPD&,'@!8E$)$`+
M;"1`BU0D$,=$)!P``````>F)3"08B4PD0(M,)!0/K,H"BTPD$(G0BY0D*`$`
M`(G%BT0D(,'A'@G-BXPD+`$``('"H>O9;HEL)""#T0")RXG1,=(!R!':,VPD
M.(E$)!")5"04BU0D2(M$)!C'1"04`````#'JB=&+5"0<`TPD$`^LT!N)\HE$
M)!"+1"08BVPD$,'@!8E$)$@+;"1(BT0D.`'IP>8>B4PD$(E,)$B)^0^LR@*)
MU0GUB[0D,`$``(EL)#B!QJ'KV6X!\(MT)"`Q[HML)$`Q]8GI`<&+1"00BU0D
M%(G+B<;!X`6)UXE$)$"+;"1`#ZS^&XM$)!B+5"0<"?7'1"0<``````'K,?^)
MWHE<)$")P8G3P>`>BY0D.`$```^LV0*)RPG#BT0D(('"H>O9;HG=B5PD((M<
M)#@!T(GZ,>N+;"1(,=V)Z0'!B?`/K-`;BU0D%(E$)!B)\(ML)!C!X`6)1"1(
M"VPD2(G3BT0D$(N4)$`!```!Z8E,)!B)3"1(B<$/K-D"P>`>B<V+C"1$`0``
M"<6!PJ'KV6Z+1"0XB6PD.(/1`(G+B=$QT@'($=HS;"0@B40D$(E4)!2+5"1`
MBT0D&#'JB=&+5"0<`TPD$`^LT!N)\HE$)!"+1"08BVPD$,=$)!0`````P>`%
MB40D0`ML)$"+1"0@`>G!YAZ)3"1`B4PD$(GY#ZS*`HG5BU0D%`GUB[0D2`$`
M`(EL)"")UXM4)!S'1"0<`````('&H>O9;@'PBW0D.#'NBVPD2#'UB>D!P8M$
M)!")RXG&P>`%B40D2(ML)$@/K/X;BT0D&`GU`>LQ_XG>B5PD2(G!B=/!X!Z+
ME"10`0``#ZS9`HG+"<.+1"0X@<*AZ]ENB=V)7"0XBUPD(`'0B?HQZXML)$`Q
MW8GI`<&)\`^LT!N+5"04B40D&(GPBVPD&,'@!8E$)$`+;"1`B=.+1"00`>F)
M3"1`B4PD&(G!#ZS9`HN4)%@!``#!X!Z)S8N,)%P!```)Q8M$)""!PJ'KV6Z)
M;"0@@]$`B<N)T3'2`<@1VC-L)#B)1"00B50D%(M4)$B+1"08QT0D%``````Q
MZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#!X`6)1"1("VPD2(M$)#@!
MZ<'F'HE,)!")3"1(B?D/K,H"B=6+5"04"?6+M"1@`0``B6PD.(G7BU0D'('&
MH>O9;@'PBW0D(#'NBVPD0#'UB>D!P8M$)!")RXG&P>`%B40D0(ML)$`/K/X;
MBT0D&`GU`>LQ_XG>B5PD0(G!B=/!X!Z+E"1H`0``#ZS9`HG+"<.+1"0@@<*A
MZ]ENB=V)7"0@BUPD.,=$)!P``````=")^C'KBVPD2#'=B>D!P8GP#ZS0&XM4
M)!2)1"08B?"+;"08P>`%B40D2`ML)$B)TXM$)!"+E"1P`0```>F)3"08B4PD
M2(G!#ZS9`L'@'HG-BXPD=`$```G%@<*AZ]ENBT0D.(EL)#B#T0")RXG1,=(!
MR!':,VPD((E$)!")5"04BU0D0(M$)!C'1"04`````#'JB=&+5"0<`TPD$`^L
MT!N)\HE$)!"+1"08BVPD$,'@!8E$)$`+;"1``>G!YAZ)3"1`B4PD$(GY#ZS*
M`HG5"?6+M"1X`0``BT0D((EL)""+5"04@<:AZ]EN`?"+="0XB=>+5"0<QT0D
M'``````Q[HML)$@Q]8GI`<&+1"00B<N)QL'@!8E$)$B+;"1(#ZS^&XM$)!@)
M]0'K,?^)WHE<)$B)P8G3P>`>BY0D@`$```^LV0*)RPG#BT0D.('"H>O9;HG=
MB5PD.(M<)"`!T(GZ,>N+;"1`,=V)Z0'!B?`/K-`;BU0D%(E$)!B)\(ML)!C!
MX`6)1"1`"VPD0(G3BT0D$(N4)(@!```!Z8E,)$")3"08B<$/K-D"P>`>B<V+
MC"2,`0``"<6!PJ'KV6Z+1"0@B6PD((/1`(G+B=$QT@'($=HS;"0XB40D$(E4
M)!2+5"1(BT0D&,=$)!0`````,>J)T8M4)!P#3"00#ZS0&XGRB40D$(M$)!B+
M;"00P>`%B40D2`ML)$B+1"0X`>G!YAZ)3"1(B4PD$(GY#ZS*`HG5BU0D%`GU
MB[0DD`$``(EL)#B)UXM4)!R!QJ'KV6X!\(MT)"`Q[HML)$`Q]8GI`<&+1"00
MB<N)QL'@!8E$)$"+;"1`#ZS^&XM$)!@)]0'K,?^)WHE<)$")P8G3P>`>BY0D
MF`$```^LV0*)RPG#BT0D(('"H>O9;HG=B5PD((M<)#@!T(GZ,>N+;"1(,=V)
MZ0'!B?`/K-`;B40D&(GPBVPD&,'@!8E$)$@+;"1(BT0D$(M4)!3'1"0<````
M``'IB=.+E"2@`0``B4PD&(E,)$B)P0^LV0+!X!Z)S8N,)*0!```)Q8'"H>O9
M;HM$)#B);"0X@]$`B<N)T3'2`<@1VC-L)"")1"00B50D%(M4)$"+1"08QT0D
M%``````QZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#!X`6)1"1`"VPD
M0(M$)"`!Z<'F'HE,)!")3"18B?D/K,H"BWPD2(G5BU0D%`GUB[0DJ`$``(EL
M)$"!QJ'KV6X!\(MT)#@Q[C'WB?F)UP'!BT0D$(G+B<;!X`4/K/X;"<8!\S'_
MB5PD2(M$)!B)WHM4)!R)P<'@'HG3BY0DL`$```^LV0*)RXN,)+0!```)PX'"
MH>O9;HM$)#B)W8/1`(EL)"")RXG1,=(!R!':BUPD0(E$)!B)5"0<BU0D6(GP
MQT0D'``````QZS':B=&)^@-,)!@/K-`;BU0D%(E$)!B)\(ML)!C!X`6)1"0X
M"VPD.(G3BT0D$(N4)+@!```!Z8E,)!B)3"18B<$/K-D"P>`>B<T)Q8'"W+P;
MCXM$)$")T8M4)"");"0X`<&)T"-4)#@)Z"-$)$B)5"00BU0D'(G%"VPD$(M$
M)!@!Z0^LT!N)\HE$)!"+1"08P>`%B40D0(ML)!`+;"1`BT0D(,=$)!0`````
MQT0D)``````!Z<'F'HE,)$B)3"00B?D/K,H"B=,)\XG?BYPDP`$``(G^B?J)
M?"1`@</<O!N/B=D!P8M$)#@)QB-T)%@APHM$)!")]8G&"=6+5"04`>G!X`6)
M1"0@BVPD((G+B=>+E"3(`0``#ZS^&XM\)!S'1"0<``````GUBW0D&`'KB5PD
M((E<)%B)^XGQP>8>BWPD0`^LV0*)\(G.BTPD2`G&BT0D.('"W+P;CXGSB?6)
M="0X`=`)^R'](=F)ZXG"B<V+1"0@"=T!ZHG1BU0D)(G&P>`%B<N)UXN4)-`!
M```/K/X;BWPD%`G&BT0D0`'SBW0D$(E<)$B)7"08B?N)\<'F'@^LV0*+7"0X
MQT0D%`````")S8M,)%@)]8'"W+P;CXG>`=`AZPGNB<*+1"08(?&);"1`"=D!
MRHG&P>`%B=&+5"0<B40D$(ML)!")RXG7BY0DV`$```^L_AN+?"0DQT0D)```
M```)]8MT)"`!ZXML)$")7"18B5PD$(G[B?'!YAX/K-D"B?")SXM,)$@)QXM$
M)#B!PMR\&X^)_HG[B7PD.`'0">XAZR'QB<*+1"00B<T)W0'JB<;!X`6)T8M4
M)!2)1"0@BVPD((G+B=>+E"3@`0``#ZS^&XM\)!P)]8MT)!@!ZXE<)"")7"1(
MB?N)\<'F'HM\)#@/K-D"B?")SHM,)%@)QHM$)$"!PMR\&X^)\XET)$`!T`G[
M(=F)\XG"(?N)S8M$)"`)W0'JB=&+5"0DB<;!X`6)RXG7#ZS^&PG&`?.)7"18
MBW0D$(M\)!2)7"08BY0DZ`$``(M$)#B)\<'F'L=$)!P`````B?O'1"04````
M``^LV0*+7"1`B<V+3"1("?6!PMR\&X^)W@'0(>L)[HG"BT0D&"'QB6PD.`G9
M`<J)QL'@!8G1BU0D'(E$)!"+;"00B<N)UXN4)/`!```/K/X;BWPD),=$)"0`
M````"?6+="0@`>N+;"0XB5PD$(E<)$B)^XGQP>8>#ZS9`HGPB<^+3"18"<>+
M1"1`@<+<O!N/B?Z)^XE\)$`!T`GN(>LA\8G"BT0D$(G-"=T!ZHG&P>`%B=&+
M5"04B40D((ML)"")RXG7BY0D^`$```^L_AN+?"0<"?6+="08`>N)7"18B5PD
M((G[B?'!YAX/K-D"B?")S@G&BT0D.(M\)$"+3"1(@<+<O!N/B?.)="0XQT0D
M'``````!T`G[(=F)\XG"(?N)S8M$)"`)W0'JB=&+5"0DB<;!X`6)RXG7BY0D
M``(```^L_AN+?"04QT0D%``````)QHM$)$`!\XMT)!")7"1(B5PD&(G[B?'!
MYAX/K-D"BUPD.(G-BTPD6`GU@<+<O!N/B=X!T"'K">Z)PHM$)!@A\8EL)$`)
MV0'*B<;!X`6)T8M4)!R)1"00BVPD$(G+B=>+E"0(`@``#ZS^&XM\)"0)]8MT
M)"`!ZXML)$")7"00B5PD6(G[B?'!YAX/K-D"B?")SXM,)$@)QXM$)#B!PMR\
M&X^)_HG[B7PD.`'0">XAZR'QB<*+1"00B<T)W0'JB<;!X`6)T8M4)!2)1"0@
MBVPD((G+QT0D)`````")UXN4)!`"```/K/X;BWPD',=$)!P`````"?6+="08
M`>N)7"1(B5PD((G[B?'!YAZ+?"0X#ZS9`HGPB<Z+3"18"<:+1"1`@<+<O!N/
MB?.)="1``=`)^R'9B?.)PB'[B<V+1"0@"=T!ZHG1BU0D)(G&P>`%B<N)UXN4
M)!@"```/K/X;BWPD%,=$)!0`````"<:+1"0X`?.+="00B5PD&(E<)%B)^XGQ
MP>8>#ZS9`HM<)$")S8M,)$@)]8'"W+P;CXG>`=`AZPGNB<*+1"08(?&);"0X
M"=D!RHG&P>`%B=&+5"0<B40D$(ML)!")RXG7BY0D(`(```^L_AN+?"0D"?6+
M="0@`>N)7"1(B5PD$(G[B?'!YAX/K-D"B?")SPG'BT0D0(ML)#B+3"18@<+<
MO!N/B?Z)^XE\)$#'1"0D``````'0">XAZR'QB<*+1"00B<T)W0'JB<;!X`6)
MT8M4)!2)1"0@BVPD((G+B=>+E"0H`@``#ZS^&XM\)!S'1"0<``````GUBW0D
M&`'KB5PD6(E<)"")^XGQP>8>BWPD0`^LV0*)\(G.BTPD2`G&BT0D.('"W+P;
MCXGSB70D.`'0"?LAV8GSB<(A^XG-BT0D(`G=`>J)T8M4)"2)QL'@!8G+B=>+
ME"0P`@``#ZS^&XM\)!0)QHM$)$`!\XMT)!")7"08B5PD2(G[B?'!YAX/K-D"
MBUPD.(G-BTPD6`GU@<+<O!N/B=X!T"'K">Z)PHM$)!@A\8EL)$`)V0'*B<;!
MX`6)T8M4)!R)1"00BVPD$(G+QT0D%`````")UXN4)#@"```/K/X;BWPD),=$
M)"0`````"?6+="0@`>N+;"1`B5PD6(E<)!")^XGQP>8>#ZS9`HGPB<^+3"1(
M"<>+1"0X@<+<O!N/B?Z)^XE\)#@!T`GN(>LA\8G"BT0D$(G-"=T!ZHG&P>`%
MB=&+5"04B40D((ML)"")RXG7BY0D0`(```^L_AN+?"0<QT0D'``````)]8MT
M)!@!ZXE<)"")7"1(B?N)\<'F'HM\)#@/K-D"B?")SHM,)%@)QHM$)$"!PMR\
M&X^)\XET)$`!T`G[(=F)\XG"(?N)S8M$)"`)W0'JB=&+5"0DB<;!X`6)RXG7
MBY0D2`(```^L_AN+?"04"<8!\XMT)!")7"18B5PD&(G[BT0D.,=$)!0`````
MB?'!YAX/K-D"BUPD0(G-BTPD2`GU@<+<O!N/B=X!T"'K">Z)PHM$)!@A\8EL
M)#@)V0'*B<;!X`6)T8M4)!R)1"00BVPD$(G+B=>+E"10`@``#ZS^&XM\)"3'
M1"0D``````GUBW0D(`'KBVPD.(E<)$B)7"00B?N)\<'F'@^LV0*)\(G/BTPD
M6`G'BT0D0('"W+P;CXG^B?N)?"1``=`)[B'K(?&)PHM$)!")S0G=`>J)QL'@
M!8G1BU0D%(E$)""+;"0@B<N)UXN4)%@"```/K/X;BWPD'`GUBW0D&`'KBVPD
M2(E<)"")7"18B?N)\<'F'@^LV0*)\(G."<:+1"0X@<+6P6+*B70D&`'0,W0D
M0#'UB>D!P8M$)""+5"0DB<O'1"0<`````(G7B<;!X`4/K/X;BU0D%,=$)!0`
M````"<:+1"00`?,Q_XE<)$B)WHG3B<&+E"1@`@``P>`>#ZS9`HM<)!B)S0G%
MBT0D0('"UL%BRHEL)#@!T#'KBVPD6(GZ,=V)Z0'!B?`/K-`;BU0D)(E$)!")
M\(ML)!#!X`6)1"1`"VPD0(G3BT0D((N4)&@"```!Z8E,)!")3"1`B<$/K-D"
MP>`>B<T)Q8M$)!B!PM;!8LJ);"0@`=`S;"0XBU0D%#-L)$B)Z0'!BT0D$`^L
MT!N)\HE$)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAZ)3"1(B4PD&(GY#ZS*
M`HGPB=:+E"1P`@``BVPD0`G&BT0D.(ET)#B!PM;!8LH!T#-T)""+5"0<B=>+
M5"04QT0D%``````Q]8GI`<&+1"08B<N)QL'@!0^L_AL)QHM$)!`!\S'_B=Z)
M7"1`B=.)P8N4)'@"``#!X!X/K-D"BUPD.(G-"<6+1"0@@<+6P6+*B6PD(`'0
M,>N+;"1(B?HQW8GI`<&)\`^LT!N+5"0<B40D$(GPBVPD$,'@!8E$)$@+;"1(
MB=.+1"08BY0D@`(```'IB4PD$(E,)$B)P0^LV0+!X!Z)S0G%BT0D.('"UL%B
MRHEL)#@!T#-L)""+5"04,VPD0(GI`<&+1"00#ZS0&XGRB40D&(M$)!#!X`6)
M1"1`BVPD&`ML)$#'1"0<``````'IP>8>BVPD2(E,)$")3"08B?D/K,H"B?")
MUHN4)(@"```)QHM$)"")="0@@<+6P6+*`=`S="0XBU0D'(G7BU0D%,=$)!0`
M````,?6)Z0'!BT0D&(G+B<;!X`4/K/X;"<:+1"00`?,Q_XG>B5PD2(G3B<&+
ME"20`@``P>`>#ZS9`HM<)"")S0G%BT0D.('"UL%BRHEL)#@!T#'KBVPD0(GZ
M,=V)Z0'!B?`/K-`;BU0D'(E$)!")\(ML)!#!X`6)1"1`"VPD0(G3BT0D&(N4
M))@"```!Z8E,)$")3"00B<$/K-D"P>`>B<T)Q8M$)""!PM;!8LJ);"0@`=`S
M;"0X,VPD2(M4)!3'1"0<`````(GI`<&+1"00#ZS0&XGRB40D&(M$)!"+;"08
MP>`%B40D2`ML)$@!Z<'F'HML)$")3"1(B4PD&(GY#ZS*`HGPB=:+E"2@`@``
M"<:+1"0XB70D.('"UL%BR@'0,W0D((M4)!R)UXM4)!3'1"04`````#'UB>D!
MP8M$)!B)RXG&P>`%#ZS^&PG&BT0D$`'S,?^)WHE<)$")TXG!BY0DJ`(``,'@
M'@^LV0*+7"0XB<T)Q8M$)""!PM;!8LJ);"0@`=`QZXML)$B)^C'=B>D!P8GP
M#ZS0&XE$)!")\(ML)!#!X`6)1"1("VPD2`'IB4PD2(E,)!"+1"08BU0D',=$
M)!P`````B=.)P8N4)+`"```/K-D"P>`>B<T)Q8M$)#B!PM;!8LJ);"0X`=`S
M;"0@BU0D%#-L)$")Z0'!BT0D$`^LT!N)\HE$)!B+1"00BVPD&,'@!8E$)$`+
M;"1``>G!YAZ+;"1(B4PD0(E,)!B)^0^LR@*)\(G6BY0DN`(```G&BT0D((ET
M)""!PM;!8LH!T#-T)#B+5"0<B=>+5"04,?6)Z0'!BT0D&(G+B<;!X`4/K/X;
M"<:+1"00`?,Q_XG>B5PD2(G3B<&+E"3``@``P>`>#ZS9`HM<)"")S0G%BT0D
M.('"UL%BRHEL)#@!T#'KBVPD0(GZ,=V)Z0'!B?`/K-`;B40D$(GPP>`%B40D
M0(ML)!`+;"1`BT0D&(M4)!S'1"04`````,=$)!P``````>F)TXN4),@"``")
M3"00B4PD0(G!#ZS9`L'@'HG-"<6+1"0@@<+6P6+*B6PD(`'0,VPD.(M4)!0S
M;"1(B>D!P8M$)!`/K-`;B?*)1"08BT0D$(ML)!C!X`6)1"1("VPD2`'IP>8>
MBVPD((E,)!B)3"1(B?D/K,H"B?")UHN4)-`"```)QHM$)#B)="0X@<+6P6+*
M`=`Q]8M4)!R)[HML)$")UXM4)!0Q]8GI`<&+1"08B<N)QL'@!0^L_AL)QHM$
M)!`!\S'_B=Z)7"18B=.)P8N4)-@"``#!X!X/K-D"B<V+C"3<`@``QT0D)```
M```)Q8'"UL%BRHM$)"");"1`@]$`B<N)T3'2`<@1VHM<)#@QZXML)$@QW3';
MB>D!P8GP$=.)^@^LT!LQTHE$)!")\(ML)!#!X`6)1"0@"VPD((M$)!@!Z1'3
MB<J)P8E4)"")5"1(P>`>BU0D'(E<)$R)TXN4).`"```/K-D"B<V+C"3D`@``
M"<6!PM;!8LJ+1"0XB6PD&(/1`(G+B=$QT@'($=HS;"1`,=LS;"18B>D!P8M$
M)"`1TXM4)"0/K-`;BU0D)(E$)!"+1"0@BVPD$`^DP@7!X`6)1"0X"VPD.(E4
M)#PQT@'I$=.)RHGYB50D6(E4)!")\@^LR@+!YAZ)7"1<QT0D%`````")\(G6
MBY0DZ`(```G&BT0D0(ML)$B)="0X@<+6P6+*`=`S="08BU0D%(G7BU0D)#'U
MB>D!P8M$)!")TXM4)!")QL'@!0^L_AL)QHGP`<@Q_XG&BT0D((G!P>`>#ZS9
M`HM<)!2)S8M,)!0)Q8M$)!B);"1(#ZS*`L'I`HE,)"2+3"00B50D((N4)/`"
M```/I,L>P>$>@<+6P6+*B5PD%(M<)#@!T(E,)!")^C'KBVPD6#'=B>D!P8GP
M#ZS0&\'J&XE$)!B)5"0<B?")^HML)!@/I,(%P>`%B40D0`ML)$")5"1$B>@!
MR(G!`TPD*(M$)&B)P\=`!`````")"(L$)(ML)"#'0PP`````QT,4`````,=#
M'``````!\`ML)!#'0R0`````B4,(B>@#1"0(B4,0BT0D2`-$)#")0QB+1"0X
M`T0D4(E#((N$)/P"``!E,P44````=0N!Q`P#``!;7E]=P^@MT___C;8`````
MC;PG`````(7`#X2;````55=64X/L'(L-0$$%"(7)B4PD"'15#[8(@/D]=%N$
MR717B<.#PP$/M@N`^3UT!(3)=?$IPXM,)`B+*87M="R)5"0,B<:)SV:0@^P$
M4U95Z#73__^#Q!"%P'4'@'P=`#UT'X/'!(LOA>UUWH/$'#'`6UY?7<.-="8`
M,=OKN(UT)@")^BM4)`B+1"0,P?H"B1"#Q!R-1!T!6UY?7<,QP,.-=@"-O"<`
M````4XG#@^P89:$4````B40D##'`C50D"(G8Z#/___^%P'0ZC;0F`````*%`
M004(BU0D"(T4D(M*!(7)B0ITU8UV`(/"!(M*!(7)B0IU](U4)`B)V.CY_O__
MA<!US8M$)`QE,P44````=06#Q!A;P^C^T?__C;0F`````(V\)P````!55XG'
M5E.)TX/L.&6A%````(E$)"@QP#'`@#H]#Y3``<-3Z/G0__^#Q!")Q8GXC50D
M&.B9_O__A<")Q@^$]P```(/L#%#HUM#__X/$$#G%#X;+````BT0D&(T,A0``
M```/M@<\/0^$@P$``(3`#X1[`0``B?CK#8GVC;PG`````(32=`N#P`$/MA"`
M^CUU\2GXC40H`H/L#(LU0$$%"%`!SNAJU/__@\00A<")!@^$3@$``*%`004(
MBU0D&(U/`8L4D`^V!X3`B`)U%>L7C78`@\$!#[9!_X/"`83`B`)T!#P]=>S&
M`CTQP(VT)@`````/M@P#B$P"`8/``83)=?$QP(M\)!QE,ST4````#X7Y````
M@\0L6UY?7<.-M@````"#PP$/MD/_@\8!A,"(1O]U[^O,D(UT)@"+%4!!!0B+
M`H7`#X2M````,?:-M@````"#Q@&+!+*%P'7VC02U"````(L-@$4%"(7)=#6#
M[`A04N@;T___@\00A<"C0$$%"`^$?````(T,M0````#'1+`$`````(ET)!CI
MP_[__XUV`(E4)`B#[`S'!8!%!0@!````4.A9T___@\00A<!T0XT,M0````"#
M[`11BU0D$(E,)!12B40D%%#H]-'__XM$)!B#Q!"+3"0,HT!!!0CKGC'`Z9S^
M__^X"````#'VZ6#___^X_____^GV_O__Z.#/__]55U93B<:![(P```!EH10`
M``")1"1\,<"%]G0%@#X`=1^+1"1\93,%%`````^%'P$``('$C````%M>7UW#
MC78`@^P,5NBWT/__@\00A<")QW3/C;8`````@^P,5^B?S___@\00A<")PP^$
MN@```(![""X/A(@```"#[`R-:PA6Z(S.__^)+"2)1"0<Z(#.__^+3"0<C40!
M`HD$).A@TO__B<-86E56:%#@!`AJ_VH!4^AKTO__@\0<C40D'%!3:@/HR\__
M_X/$$(/X_W0/#[=$)"1F)0#P9CT`0'1L@^P,4^B+T?__@\00@^P,4^C?T/__
M@\00Z5____^-M"8`````#[9#"83`#X1,____/"X/A63___^`>PH`#X0Z____
MZ57___^0C70F`(/L#%?HG\___XDT).@'T?__@\00Z>#^__^-M"8`````B=CH
ML?[__^N7Z(K.__^-=@"-O"<`````5E.#[!#_-4A!!0CH$,___XN`@````%N+
M<`3_-4A!!0CH^\[__P^V6&58_S5(004(@^-_Z.C.__^+0`0/MT`0P>`'"<-F
MB5X"6/\U2$$%".C,SO__BX"`````BU@$6/\U2$$%".BWSO__@\0,:@!H&>($
M"%#H9\___XE#'%C_-4A!!0CHF,[__XN`@````(M8!%C_-4A!!0CH@\[__XN`
M:`,``(E#(%C_-4A!!0CH;L[__XN`@````%J+6`3_-4A!!0CH6<[__XN(\```
M`(/$$#'2A<ET&H/L#/\U2$$%".@\SO__BX#P````@\00BU!P@^P,B5,D_S5(
M004(Z!_.__^+@(````"+0`3'0"@`````6/\U2$$%".@#SO__BX"`````BT`$
MQT`8`````%K_-4A!!0CHY\W__XN`@````%F+6`3_-4A!!0CHTLW__XN`!`(`
M`(E#+(/$%%M>PXUV`%.)PX/L%/\U2$$%".BOS?__C9#\````@\0,4E-J`^B]
MS?__@\00A<!T#H/$"#'`6\.-M"8`````@^P,_S5(004(Z'K-__\/MX`(`0``
M@\009B4`\&8]`$!T(H/L#/\U2$$%".A8S?__#[>`"`$``(/$$&8E`/!F/0"@
M=:Z#[`AJ`E/H6<S__X/$$(7`#Y3`@\0(#[;`6\.)]HV\)P````!55XG'5E.)
MU8'L(`0``&6A%````(F$)!`$```QP&C_`P``C70D%%9H5N`$".@OS___@\00
MA<!^8(U8_X!\'`P`=$Z)PX/L!%-J+U;HP,O__X/$$(7`=$&#[`S_-4A!!0CH
MN\S__U-65U#HPL[__X/$((N$)`P$``!E,P44````=36!Q!P$``!;7E]=PXUT
M)@"%VW6PC70F`(/L#/\U2$$%".AZS/__@\0,55=0Z/_+__^#Q!#KN^C%R___
MD(UT)@"#[!C_-4A!!0CH4LS__VA*X@0(:`"3!`AH9>`$"%#H/<W__X/$+,.)
M]HV\)P````"#[!C_-4A!!0CH(LS__XD$).BZ____6/\U2$$%".@.S/__6EEJ
M`&@9X@0(:!GB!`AH\-H$"&B!X`0(4.B0S?__@\0LPXVV`````(V_`````#'`
MPXVV`````(V\)P````!55U93@>PL!```BYPD0`0``(U4)!B+O"1$!```9:$4
M````B80D'`0``#'`N)C@!`CHV_?__X/L"(G&:B]3Z`[*__^#Q!"%P'0MB=JX
MH>`$".CK^/__B=B+C"0<!```93,-%`````^%2P$``('$+`0``%M>7UW#@^P,
M4^CAR?__6EF)1"04:*[@!`A7Z)#*__^#Q!")Q8M$)`R-?"0<@\`!B40D#(UT
M)@"%[72=@'T``'4%O9;@!`B%]G05@^P(55;HN\O__X/$$(7`#X2>````@^P,
M5>B'R?__@\00@'P%_R]U%)"-="8`@^@!@'P%_R_&1`4``'3QBTPD#(T4`8'Z
M_P,```^//____X/L!%-HL.`$"%5HU.$$"&@`!```:@%7Z$K-__^#Q!3_-4A!
M!0CHG,K__X/$#`7\````4%=J`^B;RO__@\00A<!U(H/L#/\U2$$%".AVRO__
M#[>`"`$``(/$$&8E`/!F/0"`=!F#[`AHKN`$"&H`Z*/)__^#Q!")Q>DA____
M@^P(:@%7Z%[)__^#Q!"%P'75B?JXH>`$".B;]___@^P,5^@"R?__@\00Z:'^
M___H=<G__Y"-="8`BT0D!`^V"(3)=""-4`'K"@^V"H/"`83)=!&`^2]U\0^V
M"HG0@\(!A,EU[_/#C78`4X/L&(M<)""%VW1<#[83A-)T58A4)`^#[`Q3Z%#(
M__^-1`/_@\00#[94)`\YPW(/ZRJ-M@````"#Z`$YV'0=@#@O=/3K#XUV`(V\
M)P````"`."]T0(/H`3G#<O0YPW4U@/HO=7*-=@"#[`QJ`NCNR___@\00A<!T
M5[HN````9HD0@\086\.-=@"-O"<`````@#@O=0>#Z`$YPW+T*=B-4`*!^@`$
M``!W)X/``6@`!```4%-H@$$%".BCRO__@\00N(!!!0B#Q!A;PXVV`````(/$
M&#'`6\/'1"0@L.`$"(/$&%OIV,?__Y"-M"8`````5U:#[#1EH10```")1"0L
M,<"A*.($"(E$)`JA+.($"(E$)`ZA,.($"(E$)!*A-.($"(E$)!:A..($"(E$
M)!JA/.($"(E$)!ZA0.($"(E$)"*A1.($"(E$)"8/MP5(X@0(9HE$)"JXLN`$
M".AQ]?__N+O@!`CH9_7__[C#X`0(Z%WU__^XS.`$".A3]?__N-/@!`CH2?7_
M_[CCX`0(Z#_U__^XF.`$".@U]?__N._@!`CH*_7__[CYX`0(Z"'U__^X`^$$
M".@7]?__N*'@!`CH#?7__[@-X00(Z`/U__^X%N$$".CY]/__C50D!+@AX00(
MZ#OT__^%P'0,B<*X^>`$".A;]?__C50D!+@RX00(Z!WT__^%P'0,B<*X1.$$
M".@]]?__C50D!+A/X00(Z/_S__^%P'0SB<*XF.`$".@?]?__NGOA!`BXT^`$
M".@0]?__BT0D+&4S!10```!U58/$-%Y?PY"-="8`C50D!+A?X00(Z+KS__^%
MP'06B<*X[^`$".C:]/__Z[F0C;0F`````(UT)!N_<.$$"+D*````\Z9UGXU4
M)"6X[^`$".BP]/__ZX_HF<;__XGVC;PG`````(/L'&6A%````(E$)`PQP*$@
M004(@_C_=!>+3"0,93,-%````'4^@\0<PXVV`````(U4)`BX[^`$".@R\___
MA<!T'@^V$(32#Y7`@/HP#Y7"#[;2(="C($$%".N]C70F`#'`Z_'H)\;__XVT
M)@````"#[`SHV,?__X/L#%#H?\?__X/$$(7`=`B+`(/$#,-FD#'`Z_:-M@``
M``"-OP````!55[^'X00(5E.[?>$$"(/L3(ML)&#'1"0@A^$$"(UT)"AEH10`
M``")1"0\,<#'1"0D?>$$",=$)"B*X00(QT0D+(#A!`C'1"0PA>$$",=$)#27
MX00(QT0D.`````#K(Y"#[`A54(E$)!CHPL;__X/$$(7`=$N%VW0JBP:)WX/&
M!(G#C50D'(GXZ$/R__^%P'0%@#@`=<J)ZHGXZ&'S__^%VW76BT0D/&4S!10`
M``!U<8/$3%M>7UW#D(VT)@````"#[`Q5Z%?$__^+3"08B40D'(D,)(E,)!CH
M0\3__XM4)!R-1`("B00DZ"/(__^#Q`R+3"0,46BNX`0(56C4X00(:O]J`5")
M1"0HZ"+(__^#Q""+5"0(B?CHY/+__^E4____Z,K$__^-=@"-O"<`````55=6
M4X'L'($``(N$)#"!``"-5"0<QT0D(*[A!`C'1"0DEN`$",=$)"@`````QT0D
M.$3A!`C'1"0\/>$$"(D$),=$)$"SX00(9:$4````B80D#($``#'`N)C@!`C'
M1"1$6N$$",=$)$B[X00(QT0D3`````#'1"0LHN$$",=$)#"_X00(QT0D-```
M``#H#_'__X7`=`F`.``/A?(#``#H_?W__X7`B<,/A`0$``"#[`Q3Z#K#__^-
M1``!@\00@^P,4.@:Q___@\00@#L`B<:)QW0JC;8`````#[8#@^P,@\,!4&C(
MX00(:O]J`5>#QP+H#,?__X/$((`[`'7<C7PD/+A$X00(ZQ.)]HV\)P````"#
MQP2+1_R%P'0VC50D'.A]\/__A<")PW3G@#@`=.+H;?;__X7`=-F#[`Q3Z`##
M__^#Q!"%P(G%=5F-M"8`````BUPD((7;=$B`.P"_`0```'46ZSR-="8`BUR\
M((7;=#"#QP&`.P!T*(G8Z"'V__^%P'3E@^P,4^BTPO__@\00A<!TU8G%ZPN)
M]HV\)P`````Q[8/L#(GS5>A#PO__@\00BPN#PP2-D?_^_O[WT2'*@>*`@("`
M=.GWPH"```!U!L'J$(/#`@#2@]L#@^P,*?.-G`,$!```4^CTQ?__B40D&%:)
MQFC-X00(:+#@!`A5:-+A!`AJ_VH!4.CSQ?__@\0H:,`!``!6Z!7"__^#Q!"#
M^/]T;8/L#/\U2$$%".@OP___@\0,!?P```!0_W0D$&H#Z#O#__^#Q!"%P'1L
M@^P,_W0D%(M$)!#_,&B0X@0(:@'_-61!!0CH5<7__X/$(#'`BXPD#($``&4S
M#10````/A<X)``"!Q!R!``!;7E]=PY#HB\'__XL`@_@1=(>#[`A0_W0D%(M$
M)!#_,&A4X@0(ZZV-M"8`````@^P,_S5(004(Z)K"__\/MX`(`0``@\009B4`
M\&8]`$`/A6[___^#[`S_-4A!!0CH=,+__XNP$`$``.B)P___@\00.<8/A4K_
M__^#[`S_-4A!!0CH4,+__P^W@`@!``"#Q!!F)?\!9CW``0^%)/___X/L#%/H
MK\3__XU4)"R)1"0<N(#A!`CH7>[__X/$$(7`#X3B"```@^P,4.CIP/__75I0
MBT0D#/\PZ"OV__^#Q!"%P(G##X2^"```@^P,4^AUP/__@\00@_@#?BV-=`/\
MO]OA!`BY!0```/.F=1N#^`0/A``'``"`?`/[+P^$]08``(VT)@````#H>_K_
M_X7`=1J#[`AJ`%/H3,#__XE$)!"#Q!"%P`^%+0$``+I[X00(N._@!`@QV^CL
M[O__Z*?#__]H&>($"%!HL.`$"(M\)!17:/3A!`AJ_VH!BW0D*%;H],/__X/$
M(.L[C;0F`````.@#P/__@S@1=4#H:</__X/#`8/L#&@9X@0(4U!HL.`$"%=H
M`N($"&K_:@%6Z+?#__^#Q#"#[`AHP`$``%;HUK___X/$$(/X_W2V@^P,_W0D
M%.A"PO__BW0D'+B8X`0(B?+H4N[__XDT).A*^O__@\00B?#IX/W__X/L#%")
M1"08Z#/Z__^+1"08B00DZ)>___^#Q!#IO_W__[BBX00(O@$```#K#HUV`(M$
MM"R#Q@&%P'0IC50D'.C,[/__A<!TZ(`X`'3C@^P,4.A:O___@\00A<!TTXG#
MZ;G[__^P#;NGX00(Z;W[__]J`FK_:NZ+="0,5NB@PO__@\0,:@:-A"04`0``
M4%;H+<'__X/$$("\)`P!````=0Z`O"0-`0``0P^$8P8``&H`:@!J`/]T)`SH
M8\+__\=$)&`!(T5GQT0D9`````#'1"1HB:O-[\=$)&P`````QT0D</[<NIC'
M1"1T`````,=$)'AV5#(0QT0D?`````#'A"2`````\.'2P\>$)(0`````````
MQX0DB`````````#'A"2,`````````,>$))``````````QX0DE`````````#'
MA"38`````````(/$$(UV`(/L!&@`@```C80D%`$``%#_="0,Z%?`__^#Q!"%
MP(G%#X[S`0``BTPD>(M<)'R)Z(GOP>`#B>[!_Q\!R(/[``^'NP$``#G!#X>S
M`0``BXPD@````(N<)(0````/K/X=B40D>(N$),@```#![QT!\<=$)'P`````
M$?N)C"2`````A<")G"2$````#X1A`0``ND````")[RG".=5^`HG7C80$B```
M`(/L!%>-C"04`0``45#H.<#__XN$)-@````!^(F$)-@```"#Q!"#^$`/A2W_
M__^-A"0,`0``*?T!QXU$)%#H:<3__XGVC;PG`````(/]/P^.TP```(GNB?N-
M=@"+`X/N0(/#0(F$)(@```"+0\2)A"2,````BT/(B80DD````(M#S(F$))0`
M``"+0]")A"28````BT/4B80DG````(M#V(F$)*````"+0]R)A"2D````BT/@
MB80DJ````(M#Y(F$)*P```"+0^B)A"2P````BT/LB80DM````(M#\(F$)+@`
M``"+0_2)A"2\````BT/XB80DP````(M#_(F$),0```"-1"10Z*+#__^#_C\/
MCTG___^#[4")Z,'H!HU0`<'@!BG%P>(&`==J1%57C80DE````%#HX[W__XFL
M)-@```"#Q!#I%/[__XUT)@"-O"0,`0``Z?3^__^-="8`BXPD@````(N<)(0`
M``"#P0&#TP#I0O[__X/L#/]T)`SHN[W__XN$))````"+E"24````BYPDB```
M`(NT)(P```")1"00B50D%(G8B?(/K-`#B<*#XC^-0@'&A!28````@(/$$(/X
M.`^/D0(``+@W````C8P4@0```"G0@_@$C5$(#X/``@``A<!T#*@"QD$(``^%
MPP,``(L\)(ML)`2(G"3'````B>J)^`^LT!B)ZHB$),````")^`^LT!")ZHVL
M).,```"(A"3!````B?@/K-`(B?*(A"3"````B?B-O"30````B(0DPP```(G8
M#ZS0&(GRB(0DQ````(G8#ZS0$(GRB(0DQ0```(G8#ZS0"(B$),8```"-1"10
MZ#'"__^+1"10BU0D5(G!B=.(A"32````#ZS9&(G3B<Z(C"3/````B<$/K-D0
MB=.(C"30````B<$/K-D(BUPD7(B,)-$```"+3"18B=J)R(B,)-8````/K-`8
MB=J(A"33````B<@/K-`0B=J+7"1DB(0DU````(G(BTPD8`^LT`B)VHB$)-4`
M``")R(B,)-H````/K-`8B=J(A"37````B<@/K-`0B=J+7"1LB(0DV````(G(
MBTPD:`^LT`B)VHB$)-D```")R(B,)-X````/K-`8B=J(A"3;````B<@/K-`0
MB=J+7"1TB(0DW````(G(BTPD<`^LT`B)VHB$)-T```")R(B,).(````/K-`8
MB=J(A"3?````B<@/K-`0B=J-G"0+`0``B(0DX````(G(#ZS0"(B$).$```")
M\.D+````D(UT)@`/M@>#QP&#[`P/ML!0:,CA!`AJ_VH!58/%`NBAO?__@\0@
M.=UUVL:$)`L!````:!GB!`B-A"3G````4&BPX`0(_W0D%&CEX00(:O]J`?]T
M)"CH:KW__X/$(.G$^?__BP0DBV@$A>T/A`3Y__^#[`Q5Z#NY__^#Q!"#^`,/
MAN_X__^-=`7\O^#A!`BY!0```/.F#X79^/__B>OITOC__[@_````*=")P8V$
M%($```"#^02-4`AS;H7)=`WVP0+&0`@`#X4_`0``C40D4.@@P/__C90DB```
M`+D.````,<")U_.KZ5#]___'00@`````@\$,QT00_`````"#X?PIR@'"@^+\
M@_H$#X(K_?__@^+\,<#'!`$`````@\`$.=!R\ND3_?__C7@,QT`(`````(G0
MQT01_`````"#Y_PI^`'(@^#\@_@$<H"#X/R)P3'`QP0'`````(/`!#G(<O+I
M9O___X"\)`X!``!!#X6/^?__@+PD#P$``$,/A8'Y__^`O"00`0``2`^%<_G_
M_X"\)!$!``!%#X5E^?__:@)J_VK&BW0D#%;HQ[O__X/$#&HIC80D%`$``%!6
MZ%2Z__]H&>($"(V$)"`!``!0:+#@!`C_="0D:.7A!`AJ_VH!_W0D..C<N___
M@\0PZ3;X__^-="8`BP0DBQCI./?__S')9HE,$/[I,?S__S'_9HE\$?[IM?[_
M_^AIN/__B?:-O"<`````55=64X/L*&6A%````(E$)!@QP/\U2$$%".CBN/__
MC50D&,9`80&XT^`$".@0Y?__@\00A<!T"8`X,0^$4`(``.C+[___@^P,_S5(
M004(Z*VX__]J"VH!:!/B!`A0Z,ZX__^#Q""%P`^$LP```(,]B$4%"`&+0`R+
M>!@/CJ`````Q]KL!````ZS&-M"8`````BT4,@^P(4*&$104(_S28Z`RY__^#
MQ!"%P'5EH8A%!0B#PP&#Q@$YV'Y;@^P,_S5(004(Z#BX__]J`%974.C^N?__
M@\0@A<!T-XLHBT4()0`$(``]``0``'2F@^P,_S5(004(Z`BX__]J`FH`55#H
MG;?__X/$(.N+D(VT)@````"AB$4%"(U0_SGR#X0P`0``@^P,_S5(004(Z-*W
M__]J`VH!:!CB!`A0Z/.W__^#Q""%P(G#=#2+0`R#[`R+,/\U2$$%".BGM___
M@\0,:!KB!`A64.@HM___BT,,@\00BQCV0PI`#X40`@``@^P,_S5(004(Z'BW
M__]J`VH!:!_A!`A0Z)FW__^#Q""%P(G&=#F-5"0(N*'@!`CHDN/__X7`B<,/
MA&@!``"+1@R#[`R+./\U2$$%".@UM___@\0,4U=0Z+JV__^#Q!"#[`S_-4A!
M!0CH&;?__XU4)!C&0&$`N)C@!`CH1^/__X/$$(7`B<.CC$4%"`^$E0```(/L
M"&C``0``4.BWM?__C5`!@\00@_H!=@F#^!$/A8X!``"+1"0,93,%%`````^%
M>`$``(/$'%M>7UW#C78`C;PG`````(/X`0^.Q_[__[L!````9I"#[`S_-4A!
M!0B#PP'HC[;__UY=5U#HAK7__X/$$#D=B$4%"'_;Z9;^__^-M@````"`>`$`
M#X2K_?__Z:']__^0@^P,_S6$104(Z/+P__^#Q!"%P*.,104(#X3K````BT8,
MBSV$104(BQB+0P@E``0@`#T`!```#X6-````BT,,@^P(5U#HQ[?__XG'BT8,
M@\00BQB+4PB!X@`$(`"!^@`$``!U1XM##%=0H81%!0C_,&@(XP0(Z,:V__^-
MM@````"AA$4%"(/L#(LXBT8,BQC_-4A!!0CHQK7__XGZB=CHG>C__X/$$.F.
M_O__@^P,_S5(004(Z*>U__]J`FH`4U#H/+7__X/$(.N>@^P,_S5(004(Z(FU
M__]J`FH`4U#H'K7__X/$(.E5____@^P,_S5(004(Z&BU__]:65-0Z+^V__^#
MQ!#IT?W__X/L#&CDX@0(Z"JV___HI;3__U"AA$4%"%/_,&@PXP0(Z!*V__]F
MD%93@^P0BW0D'%;H0>O__P^V"(/$$(G#A,ET((U0`>L*#[8*@\(!A,ET$8#Y
M+W7Q#[8*B=.#P@&$R77OZ,#M__^%P'0>A?9T&H`^`'05@^P(:,WA!`A3Z'6U
M__^#Q!`YV'0&@\0$6U[#@\0$B?!;7ND\Y/__C;8`````C;\`````@^P8_S5(
M004(Z**T__]:66K_4.A8M/__6/\U2$$%".B,M/__@\0,:@!HT,0$"%#H[+;_
M_X/$',-FD&:09I!FD%/H:KG__X'#>F```(/L&(N#'`$``(E$)`R+1"0HB40D
M"(M$)"2)1"0$BT0D((D$).@;M/__@\086\-FD&:09I!55S'_5E/H);G__X'#
M-6```(/L'(ML)#"-L^3^___H6;+__XV#X/[__RG&P?X"A?9T)XVV`````(M$
M)#B)+"2)1"0(BT0D-(E$)`3_E+O@_O__@\<!.?=UWX/$'%M>7UW#ZPV0D)"0
MD)"0D)"0D)"0\\,``%.#[`CHL[C__X'#PU\``(/$"%O#`P````$``@`E<R\E
M<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+@!005)?5$5-4`!005)?4%)/1TY!344`
M.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#
M04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%2
M7T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!
M4EE?4$%42`!32$Q)0E]0051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!4
M35``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'
M5@`8`'!E<FP`+64`+2T`````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```'!E<FQX<VDN8P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N
M9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D
M14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'
M5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[
M4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T
M92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP
M*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@
M;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIS965K(%]&2"P@+3@L
M(#(["G)E860@7T9(+"`D8G5F+"`X.PIL87-T('5N;&5S<R`D8G5F(&5Q(")<
M;E!!4BYP;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM
M>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@
M9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`]
M(%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D
M;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U
M+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA
M;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D
M9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U
M=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@
M)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U
M="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A
M8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D
M=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K
M*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D
M;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII
M9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M
M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA
M;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<
M;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I
M<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"
M54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A
M<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D
M92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\
M4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV
M>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O
M7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N
M(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR
M97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@
M/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA
M+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO
M<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@
M,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@
M-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS
M92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*
M;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D
M8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE
M;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M
M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@
M)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N
M9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?
M9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E
M;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!
M4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1?
M?2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%
M3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P
M87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%
M04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH``````````````(#____/00$;`SO@````&P```-AR___\````
M&'?__V`-```X>O__(`$``*B@__]D`0``6*'__\@!``#8H?__[`$``.BC__]L
M`@``2*7__R0#``"HIO__L`,``$BG__\,!```"*C__Z@$```XJ/__T`0``(BH
M__\(!0``F*C__QP%``!8JO__&`8``(BJ__\L!@``>*O__XP&```XK?__O`8`
M`*BM___8!@``V*W___P&```(K___;`<``&B[__],"P``.+___]P,``"XO___
M*`T``/B___^@#0``.,#__\`-``"HP/___`T``!0``````````7I2``%\"`$;
M#`0$B`$``"`````<````U''__T`$````#@A&#@Q*#PMT!'@`/QH[*C(D(D``
M``!`````$'G__V,F````00X(A0)!#@R'`T,.$(8$00X4@P5&#J`&`TTF"@X4
M0<,.$$'&#@Q!QPX(0<4.!$$+````8````(0````\G___I@````!)#@B%`D$.
M#(<#00X0A@1!#A2#!4,.,`)$#C1!#CA!#CQ!#D!(#C!7"@X40\,.$$'&#@Q!
MQPX(0<4.!$4+6@X41<,.$$'&#@Q!QPX(0<4.!````"````#H````B)___W(`
M````00X(@P)%#B`"90H."$'##@1!"WP````,`0``Y)___Q`"````00X(A0)!
M#@R'`T,.$(8$00X4@P5%#DQ7#E!(#D!:#DQ!#E!(#D`"2PY,1PY02@Y``FP*
M#A1!PPX00<8.#$''#@A!Q0X$1PL"3@Y(00Y,00Y02`Y`;PY,2PY02`Y`3@Y$
M00Y(20Y,10Y03`Y`````M````(P!``!TH?__5@$```!!#@B%`D$.#(<#00X0
MA@1!#A2#!4@.H`%L"@X40<,.$$'&#@Q!QPX(0<4.!$0+0PZL`4$.L`%(#J`!
M3PZL`4$.L`%(#J`!5PZL`40.L`%D#JP!00ZH`4$.K`%!#K`!10ZT`4(.N`%"
M#KP!00[``4@.I`%%#J@!00ZL`4(.L`%(#J`!5PZL`4$.L`%(#J`!0PZL`4$.
ML`%(#J`!=PZL`4$.L`%0#J`!`(@```!$`@``'*+__UT!````00X(A@)!#@R#
M`T,.'$8.($P.'$D.($H.'$8.(%D.'$8.($\.'$8.($@.%$(.&$4.'$$.($D.
M'$8.($\.'$8.($\.'$8.($P.'$D.($X.$$D.'$8.($X.$$8.'$D.(%8.'$8.
M(%8.'$8.($P.'$D.(%$.#$'##@A!Q@X$6````-`"``#PHO__EP````!!#@B#
M`D4.'$8.($X.%$$.&$$.'$(.($@.$$<*#@A#PPX$2`M##AQ&#B!/#A!-#AQ&
M#B!/#A!-#AA"#AQ!#B!(#A!(#@A$PPX$``"8````+`,``#2C__^[`````$$.
M"(4"00X,AP-##A"&!$$.%(,%2`ZT"%0.N`A%#KP(10[`"$@.L`A3#K0(00ZX
M"$(.O`A!#L`(2`ZP"$<.O`A&#L`(1@[$"$$.R`A!#LP(00[0"$@.L`A6"@X4
M0<,.$$'&#@Q!QPX(0<4.!$4+2PZ\"$8.P`A(#K0(00ZX"$$.O`A!#L`(2`ZP
M"``D````R`,``%BC__\G`````$,.'$8.($H.)$4.*$4.+$$.,$@.!```-```
M`/`#``!@H___1`````!##AQ&#B!.#AQ&#B!&#AQ!#AA"#AQ%#B!%#B1%#BA%
M#BQ!#C!(#@00````*`0``'BC__\#`````````/@````\!```=*/__[L!````
M00X(A0)!#@R'`T$.$(8$00X4@P5&#L`(;@[("$0.S`A!#M`(2`[`"&P*#A1!
MPPX00<8.#$''#@A!Q0X$00M##LP(00[0"$8.S`A!#L@(20[,"$$.T`A(#L`(
M:P[("$$.S`A!#M`(2`[`"$L.S`A!#M`(2`[`"'$.Q`A!#L@(10[,"$$.T`A%
M#M0(10[8"$(.W`A!#N`(2`[,"$8.T`A(#L0(1@[("$$.S`A"#M`(2`[`"$<.
MS`A&#M`(3P[`"$T.R`A%#LP(0@[0"$@.P`A*#L@(0@[,"$$.T`A(#L`(4P[,
M"$$.T`A(#L`(`!`````X!0``.*3__RT`````````7````$P%``!4I/__Z```
M``!!#@B#`D,.(%8.+$$.,$P.(`)$#BQ"#C!(#B!/"@X(0<,.!$L+80XD00XH
M00XL10XP2`X@2`H."$'##@1'"T,*#@A#PPX$00M+#@A!PPX$+````*P%``#D
MI/__MP$```!!#@B'`D$.#(8#0PY``UL!"@X,0<8."$''#@1&"P``&````-P%
M``!TIO__:0````!##B!F"@X$1PL``"````#X!0``R*;__R0`````0PX02`X<
M00X@2`X020H.!$,+`&P````<!@``U*;__R8!````00X(A0)!#@R'`T8.$(8$
M00X4@P5(#F`"4@YH00YL00YP3`Y@`D(*#A1!PPX00<8.#$''#@A!Q0X$20M#
M#FQ!#G!L#F1%#FA%#FQ!#G!%#G1"#GA"#GQ!#H`!3`Y@``#<`P``C`8``)2G
M__]7#````$$."(4"00X,AP-!#A"&!$$.%(,%1@ZP@@("I@Z\@@)!#L""`DP.
ML(("0PZ\@@)!#L""`D@.L(("50Z\@@)$#L""`D4.Q(("0@[(@@)"#LR"`D$.
MT(("2PZP@@("0PZ\@@)!#L""`D@.L(("`D,.O(("00[`@@)(#K""`E8.O(("
M0P[`@@)(#K""`FT.O(("2@[`@@)*#L2"`D<.R(("10[,@@)!#M""`D4.U(("
M0@[8@@)"#MR"`D$.X(("2`ZX@@)%#KR"`D$.P(("2`ZP@@)(#KR"`D8.P(("
M2`ZT@@)&#KB"`D0.O(("0@[`@@)(#K""`D<.O(("1`[`@@)&#L2"`D4.R(("
M0@[,@@)&#M""`D@.L(("7`H.%$'##A!!Q@X,0<<."$'%#@1""T\*#KB"`D$.
MO(("1`[`@@)&#L2"`D4.R(("20M##KR"`D8.P(("3PZP@@)1#KR"`D8.P(("
M4PZP@@)+#KR"`D8.P(("3PZP@@)1#KR"`D$.P(("6@ZP@@)+#KR"`D$.P(("
M1@Z\@@)!#KB"`D$.O(("1@[`@@)(#K""`DT.O(("00[`@@)(#K""`GX.N(("
M0@Z\@@)!#L""`DP.L(("8PZT@@)!#KB"`D4.O(("10[`@@)%#L2"`D(.R(("
M0@[,@@)%#M""`D@.L(("7@Z\@@)%#L""`D$.Q(("00[(@@)%#LR"`D$.T(("
M10[4@@)"#MB"`D(.W(("00[@@@)(#K""`D,.N(("10Z\@@)!#L""`D@.L(("
M2`Z\@@)$#L""`F`.L(("2@Z\@@)!#L""`E@.L(("=`Z\@@)!#L""`D@.L(("
M60ZT@@)"#KB"`D(.O(("10[`@@)(#K2"`D(.N(("2`Z\@@)!#L""`D@.L(("
M6@ZT@@)"#KB"`D(.O(("1`[`@@("E0ZP@@)&#K2"`D4.N(("2`Z\@@)$#L""
M`D@.L(("`HP.M(("00ZX@@)(#KR"`D$.P(("6`ZP@@(#!`$.M(("00ZX@@)!
M#KR"`D@.P(("3PZP@@)U#KR"`D0.P(("`D0.L(("`P4"#KR"`D0.P(("10[$
M@@)"#LB"`D(.S(("00[0@@)+#K""`E$.M(("2`ZX@@)%#KR"`D0.P(("10[$
M@@)"#LB"`D(.S(("1`[0@@)(#K""`E8.O(("00[`@@)(#K""`@,C`0ZT@@)"
M#KB"`D(.O(("10[`@@)(#K2"`D(.N(("2`Z\@@)!#L""`DH.Q(("2`[(@@)%
M#LR"`D0.T(("10[4@@)"#MB"`D(.W(("1`[@@@)(#K""`@```(P!``!L"@``
M%+#__\X#````00X(A0)!#@R'`T$.$(8$00X4@P5##CQ2#D!:#C!5#CQ&#D!'
M#D1"#DA%#DQ!#E!(#C!Q#CA!#CQ(#D!(#C!6#CQ&#D!'#D1!#DA!#DQ!#E!(
M#C!8#CQ&#D!'#D1"#DA!#DQ!#E!(#C!=#CQ&#D!'#D1"#DA%#DQ!#E!(#C!,
M#CQ(#D!(#C1%#CA!#CQ!#D!+#C!/#CQ&#D!'#D1"#DA%#DQ!#E!(#C!D#CQ(
M#D!(#C1!#CA!#CQ!#D!(#C!##CQ&#D!:#C!2#CA%#CQ!#D!+#C!B"@X40<,.
M$$'&#@Q!QPX(0<4.!$L+4PX\1@Y`20X\00XX00X\00Y`2`XP9@X\1@Y`2`XP
M<0XX00X\00Y`30XP5PH.-$$..$<./$4.0$L+2`X\30Y`40XP2`X\1@Y`1PY$
M0@Y(00Y,00Y02`XP10X\1@Y`1PY$0@Y(00Y,00Y02`XP2`X\1@Y`1@X\00XX
M00X\00Y`2`XP2`H./$4.0$4+1@XT1@XX0@X\10Y```!(````_`L``%2R__]T
M`````$$."(8"00X,@P-##AQ%#B!+#A![#AA%#AQ!#B!(#A!'"@X,0<,."$'&
M#@1!"T,.#$/##@A!Q@X$````-````$@,``"(LO__.`````!##AQ&#B!&#AQ!
M#AA"#AQ!#B!&#AQ&#B!(#A1"#AA%#AQ!#B!(#@0\````@`P``+!I__\B`@``
M`$0,`0!'$`4"=0!%#P-U=`80!@)U?!`#`G5X`Z,!"L$,`0!!PT'&0<5##`0$
M00L`'````,`,``!0LO__.@````!!#@B#`DX.(&D."$'##@0X````X`P``'"R
M__]A`````$$."(4"00X,AP-##A"&!$$.%(,%3@XP`D@.%$'##A!!Q@X,0<<.
M"$'%#@00````'`T``*2R__\"````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"0F00(<)D$
M"``````!`````0````$````*`@```0```!4"```!````'P(```$```!N`@``
M`0```+8#```,````/)($"`T````TX`0(&0```.`^!0@;````!````!H```#D
M/@4('`````0```#U_O]OJ($$"`4```"0B00(!@````"#!`@*````(@4```L`
M```0````%0`````````#`````$`%"`(````8`@``%````!$````7````))`$
M"!$```#TCP0($@```#`````3````"````/[__V^$CP0(____;P(```#P__]O
MLHX$"```````````````````````````````````````````````````````
M``````````````#L/@4(``````````!VD@0(AI($"):2!`BFD@0(MI($",:2
M!`C6D@0(YI($"/:2!`@&DP0(%I,$"":3!`@VDP0(1I,$"%:3!`AFDP0(=I,$
M"(:3!`B6DP0(II,$"+:3!`C&DP0(UI,$".:3!`CVDP0(!I0$"!:4!`@FE`0(
M-I0$"$:4!`A6E`0(9I0$"':4!`B&E`0(EI0$"*:4!`BVE`0(QI0$"-:4!`CF
ME`0(]I0$"`:5!`@6E00()I4$"#:5!`A&E00(5I4$"&:5!`AVE00(AI4$"):5
M!`BFE00(MI4$",:5!`C6E00(YI4$"/:5!`@&E@0(%I8$"":6!`@VE@0(1I8$
M"%:6!`AFE@0(=I8$"(:6!`B6E@0(``````````#_____=.,$"$=#0SH@*$1E
M8FEA;B`T+CDN,2TQ."D@-"XY+C$`1T-#.B`H1&5B:6%N(#0N."XS+3$S*2`T
M+C@N,P``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG
M;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O
M="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````
M``````````````````````````````````L````!`````@```%2!!`A4`0``
M#0```````````````0`````````3````!P````(```!D@00(9`$``"``````
M``````````0`````````(0````<````"````A($$"(0!```D````````````
M```$`````````#0```#V__]O`@```*B!!`BH`0``6`$```4`````````!```
M``0````^````"P````(`````@P0(``,``)`&```&`````0````0````0````
M1@````,````"````D(D$")`)```B!0`````````````!`````````$X```#_
M__]O`@```+*.!`BR#@``T@````4``````````@````(```!;````_O__;P(`
M``"$CP0(A`\``'`````&`````@````0`````````:@````D````"````](\$
M"/0/```P````!0`````````$````"````',````)````0@```"20!`@D$```
M&`(```4````,````!`````@```!\`````0````8````\D@0(/!(``",`````
M``````````0`````````=P````$````&````8)($"&`2``!`!```````````
M```0````!````((````!````!@```*"6!`B@%@``DDD`````````````$```
M``````"(`````0````8````TX`0(-&```!0```````````````0`````````
MC@````$````"````2.`$"$A@``!`/P`````````````(`````````)8````!
M`````@```(@?!0B(GP``Y```````````````!`````````"D`````0````(`
M``!L(`4(;*```#`-``````````````0`````````K@````X````#````X#X%
M"."N```$```````````````$`````````+H````/`````P```.0^!0CDK@``
M!```````````````!`````````#&`````0````,```#H/@4(Z*X```0`````
M``````````0`````````RP````8````#````[#X%".RN```0`0``!@``````
M```$````"````-0````!`````P```/P_!0C\KP``!```````````````!```
M``0```#9`````0````,`````0`4(`+```!@!``````````````0````$````
MX@````$````#````&$$%"!BQ```0```````````````$`````````.@````(
M`````P```$!!!0@HL0``5`0`````````````0`````````#M`````0```#``
M````````*+$``#H```````````````$````!`````0````,`````````````
9`&*Q``#V```````````````!````````````
